==> alive_flutter_plugin-0.0.3.tar.gz: ios/Classes/AliveFlutterPlugin.m <==
#import "AliveFlutterPlugin.h"
#import <NTESLiveDetect/NTESLiveDetect.h>
#import "AlivePlatformViewFactory.h"
#if __has_include(<alive_flutter_plugin/alive_flutter_plugin-Swift.h>)
#import <alive_flutter_plugin/alive_flutter_plugin-Swift.h>
#else
// Support project import fallback if the generated compatibility header
// is not copied when this plugin is created as a library.
// https://forums.swift.org/t/swift-static-libraries-dont-copy-generated-objective-c-header/19816
#import "alive_flutter_plugin-Swift.h"

#endif

@interface AliveFlutterPlugin()

@property (nonatomic, strong) NTESLiveDetectManager *detector;
@property (nonatomic, copy) NSDictionary *params;

@property (nonatomic, copy) NSString *businessID;
@property (nonatomic, assign) int timeout;

@end

@implementation AliveFlutterPlugin

+ (AliveFlutterPlugin *)sharedInstance {
    static dispatch_once_t onceToken = 0;
    static AliveFlutterPlugin *sharedObject = nil;
    dispatch_once(&onceToken, ^{
        sharedObject = [[AliveFlutterPlugin alloc] init];
    });
    
    return sharedObject;
}

NSObject<FlutterPluginRegistrar>* _jv_registrar;

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {

    FlutterMethodChannel* channel = [FlutterMethodChannel methodChannelWithName:@"alive_flutter_plugin" binaryMessenger:[registrar messenger]];
    _jv_registrar = registrar;
    AliveFlutterPlugin* instance = [[AliveFlutterPlugin alloc] init];
    instance.channel = channel;
    [registrar addMethodCallDelegate:instance channel:channel];

    FlutterViewController *view = (FlutterViewController *)[UIApplication sharedApplication].delegate.window.rootViewController;
    FlutterEventChannel* eventChannel= [FlutterEventChannel eventChannelWithName:@"yd_alive_flutter_event_channel" binaryMessenger:view.binaryMessenger];
    [eventChannel setStreamHandler:[AliveFlutterPlugin sharedInstance]];
    
    [registrar registerViewFactory:[AlivePlatformViewFactory sharedInstance] withId:@"com.flutter.alive.imageview"];
}

- (FlutterError* _Nullable)onListenWithArguments:(id _Nullable)arguments
                                      eventSink:(FlutterEventSink)events {
      if (events) {
          [AliveFlutterPlugin sharedInstance].eventSink = events;
      }

    return nil;
}

- (FlutterError * _Nullable)onCancelWithArguments:(id _Nullable)arguments {
    return nil;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *methodName = call.method;
    if ([methodName isEqualToString:@"startLiveDetect"]) {
        [self startLiveDetect:call result:result];
    } else if ([methodName isEqualToString:@"stopLiveDetect"]) {
        [self stopLiveDetect];
    } else if ([methodName isEqualToString:@"init"]) {
        [self init:call result:result];
    }  else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)init:(FlutterMethodCall*)call result:(FlutterResult)resultDict {
    NSDictionary *arguments = call.arguments;
    self.timeout = 0;
    if ([arguments isKindOfClass:[NSDictionary class]]) {
        self.businessID = [arguments objectForKey:@"businessID"];
        int time = [[arguments objectForKey:@"timeout"] intValue];
        if (time <= 0) {
            self.timeout = 30;
        } else {
            self.timeout = time;
        }
    }
}

- (void)startLiveDetect:(FlutterMethodCall*)call result:(FlutterResult)resultDict {
  dispatch_async(dispatch_get_main_queue(), ^{
      [self stopLiveDetect];
      AlivePlatformViewObject *object = [AlivePlatformViewFactory sharedInstance].myPlatformViewObject;
      UIImageView *imageView = object.imageView;
      self.detector = [[NTESLiveDetectManager alloc] initWithImageView:imageView withDetectSensit:NTESSensitEasy];

      [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(liveDetectStatusChange:) name:@"NTESLDNotificationStatusChange" object:nil];
    
     [self.detector setTimeoutInterval:(NSTimeInterval)self.timeout];
     __weak __typeof(self)weakSelf = self;
     [self.detector startLiveDetectWithBusinessID:self.businessID actionsHandler:^(NSDictionary * _Nonnull params) {
         dispatch_async(dispatch_get_main_queue(), ^{
             NSString *actions = [params objectForKey:@"actions"];
             if (actions && actions.length != 0) {
                 resultDict(params);
             } else {
             }
         });
     } completionHandler:^(NTESLDStatus status, NSDictionary * _Nullable params) {
         dispatch_async(dispatch_get_main_queue(), ^{
             weakSelf.params = params;
             [weakSelf showToastWithLiveDetectStatus:status];
         });
     }];
  });
}

- (void)stopLiveDetect {
    [self.detector stopLiveDetect];
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)getSDKVersion:(FlutterMethodCall*) call result:(FlutterResult)resultDict {
    NSString *version = [self.detector getSDKVersion];
    NSDictionary *dict = @{@"version":version?:@""};
    resultDict(dict);
}

- (void)liveDetectStatusChange:(NSNotification *)infoNotification {
    NSDictionary *userInfo = infoNotification.userInfo;
    NSLog(@"userInfo：%@", userInfo);
    NSString *value = [userInfo objectForKey:@"exception"];
    NSDictionary *infoDict = [userInfo objectForKey:@"action"];
    NSNumber *key = [[infoDict allKeys] firstObject];
    if (value) {
        NSDictionary *callbackDict = Nil;
        NSString *statusText = @"";
        switch ([value intValue]) {
            case 1:
                statusText = @"保持面部在框内";
                break;
            case 2:
                statusText = @"环境光线过暗";
                break;
            case 3:
                statusText = @"环境光线过亮";
                break;
            case 4:
                statusText = @"请勿抖动手机";
                break;
            default:
                statusText = @"";
                break;
            }
        
        callbackDict = @{
            @"message": statusText,
            @"type":@"exception"
        };
        if ([AliveFlutterPlugin sharedInstance].eventSink) {
            [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
        }
        dispatch_async(dispatch_get_main_queue(), ^(){

        });
        return;
      
        }
    NSDictionary *callbackDict = Nil;
    switch ([key intValue]) {
        case 0:
            callbackDict = @{
                @"currentStep": @(0),
                @"message": @("请正对手机屏幕"),
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){

            });
            break;
        case 1:
            callbackDict = @{
                @"currentStep": @(1),
                @"message": @"慢慢右转头",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){

            });
            break;
        case 2:
            callbackDict = @{
                @"currentStep": @(2),
                @"message": @"慢慢左转头",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
      
            });
            break;
        case 3:
            callbackDict = @{
                @"currentStep": @(3),
                @"message": @"请张张嘴",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
    
            });
            break;
        case 4:
            callbackDict = @{
                @"currentStep": @(4),
                @"message": @"请眨眨眼",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
    
            });
            break;
        case -1:
            break;
        default:
            break;
       }
}

- (void)showToastWithLiveDetectStatus:(NTESLDStatus)status {
    NSString *token;
    if ([self.params isKindOfClass:[NSDictionary class]]) {
        token = [self.params objectForKey:@"token"];
    }
    NSDictionary *callbackDict;
    switch (status) {
        case NTESLDCheckPass:
           callbackDict = @{
                @"message": @"人脸识别检测通过",
                @"token": token ?:@"",
                @"type":@"checked"
           };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                 
            });
            break;
        case NTESLDCheckNotPass:
            callbackDict = @{
                 @"message": @"人脸识别检测未通过",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
             
            });
            break;
        case NTESLDOperationTimeout:
            callbackDict = @{
                 @"message": @"操作超时，用户未在规定时间内完成动作",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                    
            });
            break;
        case NTESLDGetConfTimeout:
            callbackDict = @{
                 @"message": @"活体检测获取配置信息超时",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                     
            });
            break;
        case NTESLDOnlineCheckTimeout:
            callbackDict = @{
                 @"message": @"云端检测结果请求超时",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                       
            });
            break;
        case NTESLDOnlineUploadFailure:
            callbackDict = @{
                 @"message": @"云端检测上传图片失败",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                        
            });
            break;
        case NTESLDNonGateway:
            callbackDict = @{
                 @"message": @"网络未连接",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                        
            });
            break;
        case NTESLDSDKError:
            callbackDict = @{
                 @"message": @"SDK内部错误",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            break;
        case NTESLDCameraNotAvailable:
            callbackDict = @{
                 @"message": @"App未获取相机权限",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                        
            });
            break;
        default:
            callbackDict = @{
                 @"message": @"未知错误",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            break;
    }
}

@end

==> alive_flutter_plugin-0.0.5.tar.gz: ios/Classes/AliveFlutterPlugin.m <==
#import "AliveFlutterPlugin.h"
#import <NTESLiveDetect/NTESLiveDetect.h>
#import "AlivePlatformViewFactory.h"
#if __has_include(<alive_flutter_plugin/alive_flutter_plugin-Swift.h>)
#import <alive_flutter_plugin/alive_flutter_plugin-Swift.h>
#else
// Support project import fallback if the generated compatibility header
// is not copied when this plugin is created as a library.
// https://forums.swift.org/t/swift-static-libraries-dont-copy-generated-objective-c-header/19816
#import "alive_flutter_plugin-Swift.h"

#endif

@interface AliveFlutterPlugin()

@property (nonatomic, strong) NTESLiveDetectManager *detector;
@property (nonatomic, copy) NSDictionary *params;

@property (nonatomic, copy) NSString *businessID;
@property (nonatomic, assign) int timeout;

@end

@implementation AliveFlutterPlugin

+ (AliveFlutterPlugin *)sharedInstance {
    static dispatch_once_t onceToken = 0;
    static AliveFlutterPlugin *sharedObject = nil;
    dispatch_once(&onceToken, ^{
        sharedObject = [[AliveFlutterPlugin alloc] init];
    });
    
    return sharedObject;
}

NSObject<FlutterPluginRegistrar>* _jv_registrar;

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {

    FlutterMethodChannel* channel = [FlutterMethodChannel methodChannelWithName:@"alive_flutter_plugin" binaryMessenger:[registrar messenger]];
    _jv_registrar = registrar;
    AliveFlutterPlugin* instance = [[AliveFlutterPlugin alloc] init];
    instance.channel = channel;
    [registrar addMethodCallDelegate:instance channel:channel];

    FlutterViewController *view = (FlutterViewController *)[UIApplication sharedApplication].delegate.window.rootViewController;
    FlutterEventChannel* eventChannel= [FlutterEventChannel eventChannelWithName:@"yd_alive_flutter_event_channel" binaryMessenger:view.binaryMessenger];
    [eventChannel setStreamHandler:[AliveFlutterPlugin sharedInstance]];
    
    [registrar registerViewFactory:[AlivePlatformViewFactory sharedInstance] withId:@"com.flutter.alive.imageview"];
}

- (FlutterError* _Nullable)onListenWithArguments:(id _Nullable)arguments
                                      eventSink:(FlutterEventSink)events {
      if (events) {
          [AliveFlutterPlugin sharedInstance].eventSink = events;
      }

    return nil;
}

- (FlutterError * _Nullable)onCancelWithArguments:(id _Nullable)arguments {
    return nil;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *methodName = call.method;
    if ([methodName isEqualToString:@"startLiveDetect"]) {
        [self startLiveDetect:call result:result];
    } else if ([methodName isEqualToString:@"stopLiveDetect"]) {
        [self stopLiveDetect];
    } else if ([methodName isEqualToString:@"init"]) {
        [self init:call result:result];
    }  else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)init:(FlutterMethodCall*)call result:(FlutterResult)resultDict {
    NSDictionary *arguments = call.arguments;
    self.timeout = 0;
    if ([arguments isKindOfClass:[NSDictionary class]]) {
        self.businessID = [arguments objectForKey:@"businessID"];
        int time = [[arguments objectForKey:@"timeout"] intValue];
        if (time <= 0) {
            self.timeout = 30;
        } else {
            self.timeout = time;
        }
    }
}

- (void)startLiveDetect:(FlutterMethodCall*)call result:(FlutterResult)resultDict {
  dispatch_async(dispatch_get_main_queue(), ^{
    [self stopLiveDetect];
    AlivePlatformViewObject *object = [AlivePlatformViewFactory sharedInstance].myPlatformViewObject;
    UIImageView *imageView = object.imageView;
    self.detector = [[NTESLiveDetectManager alloc] initWithImageView:imageView withDetectSensit:NTESSensitEasy];

    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(liveDetectStatusChange:) name:@"NTESLDNotificationStatusChange" object:nil];
    
    [self.detector setTimeoutInterval:(NSTimeInterval)self.timeout];
    __weak __typeof(self)weakSelf = self;
    [self.detector startLiveDetectWithBusinessID:self.businessID configURL:config actionsHandler:^(NSDictionary * _Nonnull params) {
        dispatch_async(dispatch_get_main_queue(), ^{
            NSString *actions = [params objectForKey:@"actions"];
            if (actions && actions.length != 0) {
                resultDict(params);
            } else {
                
            }
        });
     } checkingHandler:^{
             
     } completionHandler:^(NTESLDStatus status, NSDictionary * _Nullable params) {
         dispatch_async(dispatch_get_main_queue(), ^{
             weakSelf.params = params;
             [weakSelf showToastWithLiveDetectStatus:status];
         });
     }];
  });
}

- (void)stopLiveDetect {
    [self.detector stopLiveDetect];
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)getSDKVersion:(FlutterMethodCall*) call result:(FlutterResult)resultDict {
    NSString *version = [self.detector getSDKVersion];
    NSDictionary *dict = @{@"version":version?:@""};
    resultDict(dict);
}

- (void)liveDetectStatusChange:(NSNotification *)infoNotification {
    NSDictionary *userInfo = infoNotification.userInfo;
    NSLog(@"userInfo：%@", userInfo);
    NSString *value = [userInfo objectForKey:@"exception"];
    NSDictionary *infoDict = [userInfo objectForKey:@"action"];
    NSNumber *key = [[infoDict allKeys] firstObject];
    if (value) {
        NSDictionary *callbackDict = Nil;
        NSString *statusText = @"";
        switch ([value intValue]) {
            case 1:
                statusText = @"保持面部在框内";
                break;
            case 2:
                statusText = @"环境光线过暗";
                break;
            case 3:
                statusText = @"环境光线过亮";
                break;
            case 4:
                statusText = @"请勿抖动手机";
                break;
            default:
                statusText = @"";
                break;
            }
        
        callbackDict = @{
            @"message": statusText,
            @"type":@"exception"
        };
        if ([AliveFlutterPlugin sharedInstance].eventSink) {
            [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
        }
        dispatch_async(dispatch_get_main_queue(), ^(){

        });
        return;
      
        }
    NSDictionary *callbackDict = Nil;
    switch ([key intValue]) {
        case 0:
            callbackDict = @{
                @"currentStep": @(0),
                @"message": @("请正对手机屏幕"),
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){

            });
            break;
        case 1:
            callbackDict = @{
                @"currentStep": @(1),
                @"message": @"慢慢右转头",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){

            });
            break;
        case 2:
            callbackDict = @{
                @"currentStep": @(2),
                @"message": @"慢慢左转头",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
      
            });
            break;
        case 3:
            callbackDict = @{
                @"currentStep": @(3),
                @"message": @"请张张嘴",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
    
            });
            break;
        case 4:
            callbackDict = @{
                @"currentStep": @(4),
                @"message": @"请眨眨眼",
                @"type":@"checking"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
    
            });
            break;
        case -1:
            break;
        default:
            break;
       }
}

- (void)showToastWithLiveDetectStatus:(NTESLDStatus)status {
    NSString *token;
    if ([self.params isKindOfClass:[NSDictionary class]]) {
        token = [self.params objectForKey:@"token"];
    }
    NSDictionary *callbackDict;
    switch (status) {
        case NTESLDCheckPass:
           callbackDict = @{
                @"message": @"人脸识别检测通过",
                @"token": token ?:@"",
                @"type":@"checked"
           };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                 
            });
            break;
        case NTESLDCheckNotPass:
            callbackDict = @{
                 @"message": @"人脸识别检测未通过",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
             
            });
            break;
        case NTESLDOperationTimeout:
            callbackDict = @{
                 @"message": @"操作超时，用户未在规定时间内完成动作",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                    
            });
            break;
        case NTESLDGetConfTimeout:
            callbackDict = @{
                 @"message": @"活体检测获取配置信息超时",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                     
            });
            break;
        case NTESLDOnlineCheckTimeout:
            callbackDict = @{
                 @"message": @"云端检测结果请求超时",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                       
            });
            break;
        case NTESLDOnlineUploadFailure:
            callbackDict = @{
                 @"message": @"云端检测上传图片失败",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                        
            });
            break;
        case NTESLDNonGateway:
            callbackDict = @{
                 @"message": @"网络未连接",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                        
            });
            break;
        case NTESLDSDKError:
            callbackDict = @{
                 @"message": @"SDK内部错误",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            break;
        case NTESLDCameraNotAvailable:
            callbackDict = @{
                 @"message": @"App未获取相机权限",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            dispatch_async(dispatch_get_main_queue(), ^(){
                        
            });
            break;
        default:
            callbackDict = @{
                 @"message": @"未知错误",
                 @"type":@"checked"
            };
            if ([AliveFlutterPlugin sharedInstance].eventSink) {
                [AliveFlutterPlugin sharedInstance].eventSink(callbackDict);
            }
            break;
    }
}

@end
